--- lisp/emacs-lisp/authors.el	6 May 2008 03:21:08 -0000	1.51
+++ lisp/emacs-lisp/authors.el	11 Sep 2008 10:54:47 -0000
@@ -1,4 +1,4 @@
 ;;; authors.el --- utility for maintaining Emacs' AUTHORS file -*-coding: iso-2022-7bit;-*-
 
 ;; Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005,
 ;;   2006, 2007, 2008 Free Software Foundation, Inc.
@@ -29,7 +29,7 @@
 
 ;;; Code:
 
-(defvar authors-coding-system 'iso-2022-7bit
+(defvar authors-coding-system 'utf-8
   "Coding system used in the AUTHORS file.")
 
 (defconst authors-many-files 20
@@ -44,13 +44,13 @@
     ("Anna M. Bigatti" "Anna Bigatti")
     ("Barry A. Warsaw" "Barry A. Warsaw, Century Computing, Inc."
      "Barry A. Warsaw, ITB" "Barry Warsaw")
-    ("Bj,Av(Brn Torkelsson" "Bjorn Torkelsson")
+    ("Björn Torkelsson" "Bjorn Torkelsson")
     ("Brian Fox" "Brian J. Fox")
     ("Christoph Wedler" "Christoph.Wedler@sap.com")
     ("Daniel Pfeiffer" "<Daniel.Pfeiffer@Informatik.START.db.de>"
      "<Daniel.Pfeiffer@Informatik.START.dbp.de>")
     ("David Gillespie" "Dave Gillespie")
-    ("David K,Ae(Bgedal" "David K..edal")
+    ("David Kågedal" "David K..edal")
     ("David M. Koppelman" "David M. Koppelman, Koppel@Ee.Lsu.Edu"
      "David Koppelman")
     ("David M. Smith" "David Smith" "David M Smith")
@@ -64,35 +64,35 @@
     ("Eric S. Raymond" "Eric Raymond")
     ("Eric Youngdale" "(Eric Youngdale at youngdale@v6550c.nrl.navy.mil)")
     ("Francis J. Wright" "Dr Francis J. Wright" "Francis Wright")
-    ("Fran,Ag(Bois Pinard" "Francois Pinard")
-    ("Francesco Potort,Al(B" "Francesco Potorti" "Francesco Potorti`")
+    ("François Pinard" "Francois Pinard")
+    ("Francesco Potortì" "Francesco Potorti" "Francesco Potorti`")
     ("Frederic Pierresteguy" "Fred Pierresteguy")
     ("Geoff Voelker" "voelker")
-    ("Gerd M,Av(Bllmann" "Gerd Moellmann")
+    ("Gerd Möllmann" "Gerd Moellmann")
     ("Hallvard B. Furuseth" "Hallvard B Furuseth")
-    ("Hrvoje Nik$,1!!(Bi$,1 '(B" "Hrvoje Niksic")
+    ("Hrvoje Nikšić" "Hrvoje Niksic")
     (nil "(afs@hplb.hpl.hp.com)")
     (nil "<Use-Author-Address-Header@\\[127.1\\]>")
     (nil "Code Extracted")
     (nil "\\`FSF")
     (nil "ISO-2022-JP")
     ("Jaeyoun Chung" "Jae-youn Chung" "Jae-you Chung" "Chung Jae-youn")
-    ("Jan Dj,Ad(Brv" "Jan D." "Jan Djarv")
+    ("Jan Djärv" "Jan D." "Jan Djarv")
     ("Jay K. Adams" "jka@ece.cmu.edu" "Jay Adams")
-    ("J,Ai(Br,At(Bme Marant" "J,Ai(Br,At(Bme Marant" "Jerome Marant")
+    ("Jérôme Marant" "Jérôme Marant" "Jerome Marant")
     ("Jens-Ulrik Holger Petersen" "Jens-Ulrik Petersen")
     ("Jeremy Bertram Maitin-Shepard" "Jeremy Maitin-Shepard")
-    ("Johan Bockg,Ae(Brd" "Johan Bockgard")
+    ("Johan Bockgård" "Johan Bockgard")
     ("John W. Eaton" "John Eaton")
     ("Jonathan I. Kamens" "Jonathan Kamens")
     ("Joseph Arceneaux" "Joe Arceneaux")
-    ("Juan Le,As(Bn Lahoz Garc,Am(Ba" "Juan-Leon Lahoz Garcia")
+    ("Juan León Lahoz García" "Juan-Leon Lahoz Garcia")
     ("K. Shane Hartman" "Shane Hartman")
-    ("Kai Gro,A_(Bjohann" "Kai Grossjohann" "Kai Gro,A_(Bjohann"
+    ("Kai Großjohann" "Kai Grossjohann" "Kai Großjohann"
      "Kai.Grossjohann@Cs.Uni-Dortmund.De"
      "Kai.Grossjohann@Gmx.Net")
     ("Karl Berry" "K. Berry")
-    ("K,Aa(Broly L$,1 q(Brentey" "K,Aa(Broly L$,1 q(Brentey" "L$,1 q(Brentey K,Aa(Broly")
+    ("Károly Lőrentey" "Károly Lőrentey" "Lőrentey Károly")
     ("Kazushi Marukawa" "Kazushi")
     ("Ken Manheimer" "Kenneth Manheimer")
     ("Kenichi Handa" "Ken'ichi Handa" "Kenichi HANDA")
@@ -101,17 +101,17 @@
     ("Kyle Jones" "Kyle E. Jones")
     ("Marcus G. Daniels" "Marcus Daniels")
     ("Mark D. Baushke" "Mark D Baushke")
-    ("Agust,Am(Bn Mart,Am(Bn" "Agustin Martin")
+    ("Agustín Martín" "Agustin Martin")
     ("Martin Lorentzon" "Martin Lorentzson")
     ("Matt Swift" "Matthew Swift")
     ("Michael R. Mauger" "Michael Mauger")
     ("Michael D. Ernst" "Michael Ernst")
-    ("Micha,Ak(Bl Cadilhac" "Michael Cadilhac")
+    ("Michaël Cadilhac" "Michael Cadilhac")
     ("Michael I. Bushnell" "Michael I Bushnell" "Michael I. Bushnell, P/Bsg")
     ("Mikio Nakajima" "Nakajima Mikio")
     ("Paul Eggert" "eggert")
     ("Paul Reilly" "(pmr@legacy.pajato.com)")
-    ("Pavel Jan,Am(Bk" "Pavel Jan,Am(Bk Ml." "Pavel Jan,Am(Bk" "Pavel@Janik.Cz")
+    ("Pavel Janík" "Pavel Janík Ml." "Pavel Janík" "Pavel@Janik.Cz")
     ("Per Abrahamsen" "Per Abhiddenware")
     ("Peter S. Galbraith" "Peter Galbraith")
     ("Peter Runestig" "Peter 'luna' Runestig")
@@ -130,8 +130,8 @@
     ("Takaaki Ota" "Tak Ota")
     ("Takahashi Naoto" "Naoto Takahashi")
     ("Teodor Zlatanov" "Ted Zlatanov")
-    ("Torbj,Av(Brn Axelsson" "Torbjvrn Axelsson")
-    ("Torbj,Av(Brn Einarsson" "Torbj.*rn Einarsson")
+    ("Torbjörn Axelsson" "Torbjvrn Axelsson")
+    ("Torbjörn Einarsson" "Torbj.*rn Einarsson")
     ("Toru Tomabechi" "Toru Tomabechi,")
     ("Vincent Del Vecchio" "Vince Del Vecchio")
     ("William M. Perry" "Bill Perry")
@@ -1,4 +1,4 @@
-;;; authors.el --- utility for maintaining Emacs' AUTHORS file -*-coding: iso-2022-7bit;-*-
+;;; authors.el --- utility for maintaining Emacs' AUTHORS file -*-coding: utf-8;-*-
 
 ;; Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005,
